@@ -151,6 +151,7 @@ sub header {
 
 				if ( exists $cf->{format} and defined $cf->{format} ) {
 					$format_names = $cf->{format};
+					no warnings 'redundant';
 					$width = length sprintf( $format_names, " " );
 				}
 
@@ -448,4 +449,4 @@ modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
-L<DBI::Shell(3)>, L<DBI(3)>, L<dbish(1)>
+L<DBI::Shell>, L<DBI>, L<dbish>
