@@ -20,9 +20,6 @@ or
 The DBI::Shell module (and dbish command, if installed) provide a
 simple but effective command line interface for the Perl L<DBI> module.
 
-DBI::Shell is very new, very experimental and very subject to change.
-Your mileage I<will> vary. Interfaces I<will> change with each release.
-
 =cut
 
 ###
@@ -41,14 +38,7 @@ use Carp;
 @ISA = qw(Exporter DBI::Shell::Std);
 @EXPORT = qw(shell);
 
-$VERSION = '11.95_03';
-
-my $warning = <<'EOM';
-
-WARNING: The DBI::Shell interface and functionality are
-=======  very likely to change in subsequent versions!
-
-EOM
+$VERSION = '11.96_01';
 
 sub new {
 	my $class = shift;
@@ -85,8 +75,6 @@ sub run {
     die "Unrecognised options: @{$sh->{unhandled_options}}\n"
 	if @{$sh->{unhandled_options}};
 
-    $sh->log($warning) unless $sh->{batch};
-
     # Use valid "dbi:driver:..." to connect with source.
     $sh->do_connect( $sh->{data_source} );
 
@@ -134,6 +122,7 @@ use Term::ReadLine;
 use Getopt::Long 2.17;	# upgrade from CPAN if needed: http://www.perl.com/CPAN
 use IO::File;
 use File::Spec ();
+use File::HomeDir ();
 
 use DBI 1.00 qw(:sql_types :utils);
 use DBI::Format;
@@ -147,6 +136,9 @@ use vars qw(@ISA);
 use constant ADD_RH => 1;	# Add the results, to rhistory.
 use constant  NO_RH => 0;	# Do not add results, to rhistory.
 
+# History saving is also provided by DBI::Shell::Completion.
+use constant HISTORY_FILE => '.dbish-builtin-history';
+
 my $haveTermReadKey;
 my $term;
 
@@ -420,6 +412,9 @@ sub default_term {
 		$mode = "in batch mode";
     } else {
 		$sh->{term} = new Term::ReadLine($class);
+		if ($sh->{term}->Features->{readHistory}) {
+			$sh->{term}->ReadHistory(File::Spec->catfile(File::HomeDir->my_home, HISTORY_FILE));
+		}
 		$mode = "";
     }
 
@@ -1131,6 +1126,13 @@ sub do_rollback {
 sub do_quit {
     my ($sh, @args) = @_;
     $sh->do_disconnect if $sh->{dbh};
+
+    if ($sh->{term}) {
+        if ($sh->{term}->Features()->{writeHistory}) {
+            $sh->{term}->WriteHistory(File::Spec->catfile(File::HomeDir->my_home, HISTORY_FILE));
+        }
+    }
+
     undef $sh->{term};
     exit 0;
 }
@@ -1957,7 +1959,8 @@ from Jochen's dbimon is bound to find it's way back in.
 
 The DBI::Shell module is Copyright (c) 1998 Tim Bunce. England.
 All rights reserved. Portions are Copyright by Jochen Wiedmann,
-Adam Marks and Tom Lowery.
+Adam Marks, Tom Lowery, Kent Fredric and Rafael Kitover. It is currently
+maintained by Dave Lambley.
 
 You may distribute under the terms of either the GNU General Public
 License or the Artistic License, as specified in the Perl README file.
